package czlib

import (
	"bytes"
	"io"
	"testing"
)

func checkFatalError(t *testing.T, err error) {
	if err != nil {
		t.Fatal(err)
	}
}

func TestDeflateInflate(t *testing.T) {
	compressInput := "hello, world\n"
	var b bytes.Buffer

	w := NewWriter(&b)
	_, err := w.Write([]byte(compressInput))
	checkFatalError(t, err)
	err = w.Close()
	checkFatalError(t, err)

	br := bytes.NewReader(b.Bytes())
	r, err := NewReader(br)
	checkFatalError(t, err)

	buf := &bytes.Buffer{}
	_, err = io.Copy(buf, r)
	checkFatalError(t, err)
	err = r.Close()
	checkFatalError(t, err)

	if buf.String() != "hello, world\n" {
		t.Errorf("output differs from expected")
	}
}
