package czlib

import (
	"bytes"
	"testing"
)

func TestDeflate(t *testing.T) {
	var b bytes.Buffer

	w := NewWriter(&b)
	_, err := w.Write([]byte("hello, world\n"))
	checkFatalError(t, err)
	err = w.Close()
	checkFatalError(t, err)

	expectedOut := []byte{120, 156, 203, 72, 205, 201, 201, 215, 81,
		40, 207, 47, 202, 73, 225, 2, 0, 33, 231, 4, 147}

	if !bytes.Equal(b.Bytes(), expectedOut) {
		t.Errorf("output differs from expected")
	}
}

func TestDeflateCustom(t *testing.T) {
	var b bytes.Buffer

	w, err := NewWriterCustom(&b, Z_BEST_COMPRESSION, Z_DEFLATED, MAX_WBITS, MAX_MEM_LEVEL, Z_DEFAULT_STRATEGY)
	checkFatalError(t, err)
	_, err = w.Write([]byte("hello, world\n"))
	checkFatalError(t, err)
	err = w.Close()
	checkFatalError(t, err)

	expectedOut := []byte{120, 218, 203, 72, 205, 201, 201, 215, 81,
		40, 207, 47, 202, 73, 225, 2, 0, 33, 231, 4, 147}

	if !bytes.Equal(b.Bytes(), expectedOut) {
		t.Errorf("output differs from expected")
	}
}
